#! /usr/bin/env python3

from tensorflow.keras.datasets.mnist import load_data
from tensorflow.keras.layers import Conv2D, Dense, Dropout, Flatten, MaxPooling2D
from tensorflow.keras.models import Sequential
from tensorflow.keras.utils import to_categorical

(trainingImages, trainingLabels), (testImages, testLabels) = load_data()

trainingImages = trainingImages.reshape((60000, 28, 28, 1))
trainingImages = trainingImages.astype('float32')
trainingImages /= 255
trainingLabels = to_categorical(trainingLabels)
trainingImageCount = trainingImages.shape[0]

testImages = testImages.reshape((10000, 28, 28, 1))
testImages = testImages.astype('float32')
testImages /= 255
testLabels = to_categorical(testLabels)
testImageCount = testImages.shape[0]

print('Trainingsdaten: {}'.format(trainingImages.shape))
print('Testdaten: {}'.format(testImages.shape))

model = Sequential()
model.add(Conv2D(32, kernel_size = (5, 5), activation = 'relu', input_shape = trainingImages[0].shape))
model.add(MaxPooling2D(pool_size = (2, 2)))
model.add(Conv2D(64, kernel_size = (5, 5), activation = 'relu'))
model.add(MaxPooling2D(pool_size = (2, 2)))
model.add(Dropout(0.5))
model.add(Flatten())
model.add(Dense(128, activation = 'relu', name = 'features'))
model.add(Dropout(0.5))
model.add(Dense(64, activation = 'relu'))
model.add(Dense(10, activation = 'softmax'))
model.summary()
model.compile(loss = 'categorical_crossentropy', optimizer = 'Adam', metrics = ['accuracy'])

epochCount = 3
model.fit(trainingImages, trainingLabels,
          batch_size = 128, epochs = epochCount,
          verbose = 1, validation_data = (testImages, testLabels))

# model.evaluate(testImages, testLabels)
